@@ -1,7 +1,7 @@
 from fabric.api import *
 import subprocess
 
-__all__ = ['ssh', 'all', 'uptime', 'upgrade', 'restart']
+__all__ = ['ssh', 'all', 'uptime', 'upgrade', 'restart', 'reboot']
 
 @task
 def all():
@@ -25,7 +25,7 @@ def upgrade():
     """
     with settings(hide('stdout'), show('running')):
         sudo('apt-get update')
-    sudo("apt-get upgrade -y")
+    sudo("apt-get upgrade")
 
 @task
 def ssh(*cmd):
@@ -49,3 +49,11 @@ def restart(service):
     if result.failed:
         sudo('start %s' % service)
 
+@task
+def reboot():
+    """
+    Reboot a host
+    """
+    sudo('reboot')
+
+
